Learn R Programming

ggdmc (version 0.1.3.9)

acf.dmc: Plot an Autocorrelation Matrix

Description

This is a wrapper function to plot a DMC object, using ggmcmc ggs_autocorrelation

Usage

acf.dmc(x, lag.max = NULL, start = 1)

Arguments

x
a DMC sample/object
lag.max
to make it compartible to acf of stats pacakge. Default is NULL
start
plot from which iteration. Default is from the first iteration.