Learn R Programming

ggdmc (version 0.1.3.9)

ggdmc: Supersonic DMC

Description

ggdmc implements graphic grammar, Rcpp, and Open MPI for Andrew Heathcote's Dynamic Models of Choice (DMC), an algorithm for fitting various evidence accumulation models via differential evolution MCMC sampler. Currently, ggdmc implements only drift-diffusion model.

Arguments

References

Turner, B. M., & Sederberg P. B. (2012). Approximate Bayesian computation with differential evolution, Journal of Mathematical Psychology, 56, 375--385. Ter Braak (2006). A Markov Chain Monte Carlo version of the genetic algorithm Differential Evolution: easy Bayesian computing for real parameter spaces. Statistics and Computing, 16, 239-249.