Learn R Programming

ggdmc (version 0.1.3.9)

mcmc.list.dmc: Create a mcmc.list in DMC format

Description

If not hyper, by default changes samples$theta to a mcmc.list object and plots If pll.chain=TRUE changes samples$pll to an mcmc object and plots posterior log-likelihood of chains. If pll.barplot=TRUE plots their means as a barplot. only.prior and only.like pick out one or other component of pll. If hyper same but at the the hyper (phi) level.

Usage

mcmc.list.dmc(samples, hyper = FALSE, start = 1, end = NA,
  save.ll = FALSE, ask = TRUE, main.pll = NULL, pll.chain = FALSE,
  pll.together = TRUE, pll.barplot = FALSE, only.prior = FALSE,
  only.like = FALSE, subject = 1, layout = NA, ...)

Arguments

samples
a data frame stored choice-RT data
hyper
a DMC model
start
starting iteration
end
end iteration
save.ll
whether save log likelihood
ask
Default TRUE
main.pll
Default NULL
pll.chain
Default FALSE
pll.together
Default TRUE
pll.barplot
Default FALSE
only.prior
plot only prior distribution
only.like
plot only likelihood
subject
plot which participant. Default the 1st
layout
graphic layout. Default NA
...
other arguments