Learn R Programming

ggdmc (version 0.1.3.9)

pick.stuck.dmc: Find Stuck Chains

Description

This function picks out the chains that get stuck.

Usage

pick.stuck.dmc(samples, hyper = FALSE, cut = 10, start = 1, end = NA,
  verbose = FALSE, digits = 2)

Arguments

samples
a DMC object/sample
hyper
whether to work on hyper parameters, namely phi
cut
cutoff point. Default 10
start
starting from which iteration. Default 1
end
calculating until which iteration. Default is the last one, extracted from the input DMC sample.
verbose
whether print out debugging information
digits
print how many digits. Default 2

Value

index of stuck chains (deviaton of ll from median < -cut)