Learn R Programming

ggdmc (version 0.1.3.9)

post.predict.ggdmc: Simulate Post-predictive Sample

Description

Make a list of probability density, quantiles and resposnes based on a posterior DMC sample. This function is to produce a data frame that can be used by ggplot2 functions.

Usage

post.predict.ggdmc(samples, n.post = 100, probs = c(1:99)/100,
  bw = "nrd0", report = 10, save.dat = FALSE)

Arguments

samples
a DMC sample/object
n.post
how many data point to simulate
probs
the quantile probability. Default c(1:99)/100
bw
bin width method. Default "nrd0", passing to density function
report
report progress
save.dat
whether to save simulation data to further modify data frame for plotting