Learn R Programming

ggdmc (version 0.1.3.9)

print_cell_p: Print accumulator x internal parameter type matrix for each cell

Description

A DMC model array, created by model.dmc is computationally efficient but it is not easy to see how parameters map to design cells. print.cell.p makes it easy to loop through cells and print the mapping.

Usage

print_cell_p(p.vector, model)

Arguments

p.vector
a parameter vector,
model
a DMC model

Examples

Run this code
model <- model.dmc(
p.map     = list(A = "1", B = "1", mean_v = "M", sd_v = "M", t0 = "1",
                 st0 = "1"),
match.map = list(M = list(s1 = 1, s2 = 2)),
factors   = list(S = c("s1", "s2")),
constants = c(st0 = 0, sd_v.false=1),
responses = c("r1","r2"),
type      = "norm")
p.vector <- c(A=3, B=4, mean_v.true=2, mean_v.false=-1, sd_v.true=0.5, t0=.2)
print_cell_p(p.vector, model)

Run the code above in your browser using DataLab