Learn R Programming

ggdmc (version 0.1.3.9)

prior.p.dmc: Makes a list of prior distribution parameters.

Description

prior.p.dmc creates a list of prior distribution an array object ("model") with a set of attributes specifying a particular model and parameterization. Call coda to summarise the model parameters in a DMC samples with multiple participants at the hyper level.

Usage

prior.p.dmc(p1, p2, lower = rep(NA, length(p1)), upper = rep(NA,
  length(p1)), dists = rep("tnorm", length(p1)), untrans = rep("identity",
  length(p1)), dist.types = c("tnorm", "beta", "gamma", "lnorm", "constant"))

Arguments

p1
the values of location parameters for each prior distribution, set as a double vector
p2
ditto for scale parameter vector
lower
lower support boundary
upper
upper support boundary
dists
indicate which prior distribution, e.g., uniform, beta etc.
untrans
whether do log transformation or not. Default is identity, namely not to transform
dist.types
allowed prior distributions in current version of DMC