Learn R Programming

ggdmc (version 0.1.3.9)

run_data: Run a Bayesian EAM Model for Fixed-effect or Random-effect

Description

These are the C++ functions hierarchical Bayesian models. The user usually should not call this function directly. Use h.run.dmc or run.dmc wrapper instead. Two parallel versions of run uses Open MPI to calculate diffusion probability density. Use them by setting cores greater than 2 in h.run.dmc

Usage

run_data(samples, setting, debug = FALSE)

run_data_parallel(samples, setting, debug = FALSE)

run_hyper(samples, setting)

run_hyper_parallel(samples, setting)

Arguments

samples
a DMC sample/object
setting
a container to store all settings for running model fitting
debug
a debugging switch to test chain randomisation. Default false

Value

a DMC sample