get.par.mat.
par.df is a data frame of parameters types, some of which may need
to be transformed, or new columns created, so that the full set of
internal parameter types, specified in type.par.names attribute in
a model data instance, required by the type of evidence accumulation model
being used, such as the norm class in one of the LBA models, is
present.transform(mdi, par.df, ...)# S3 method for rd
transform(mdi, par.df, ...)
# S3 method for norm
transform(mdi, par.df, ...)
transform.norm template sets up for n-choice LBA, \(B=b-A\)
parameterization. External parameters types: A, B, t0, mean_v,
sd_v, \(st0 = 0\) (optional).
Internal parameters types: A, b, t0, mean_v,
sd_v, \(st0 = 0\) (optional).